/*
Title: chalow default
 */

/*
ページ全体の基本的な設定。背景色や文字色など
*/
body {
	background-color: White;
}

/*
リンク文字列に関する設定
*/
a:link {
        text-decoration: none;
}

a:visited {
        text-decoration: none;
}


/*
ページトップ (とか、下) にある操作ボタンの並ぶ行の設定
*/
.adminmenu {
        text-align: left;
        margin: 0em;
	font-size: small;
}

/*
日記タイトルの設定
*/
h1 {
	text-align: left;
        border-color: #808080;
        border-style: solid;
        border-width: 1px 0 1px 0;
        padding: 0.5em;
}

/*
1日の日記全体を囲む枠の設定 (entry)
*/
div.day { 
        padding: 5px 0px 5px 0px;
	margin: 5px 0px 5px 0px;
}

/*
タイトル行全体の設定 (enrty header)
*/
h2 {
        margin: 0.0em 0.0em 0.5em 0.0em;
        padding: 0.5em 0.0em 0.5em 0.0em;
        border-color: #808080;
        border-style: solid;
        border-width: 1px 10px 1px 10px;
	background-color: #d0d0d0;
}

/*
日付の設定 (in enrty header)
*/
span.date {
        padding: 0em 0.5em 0em 0.5em;
}

/*
タイトルを除いた1日の日記本文全体の設定 (items)
*/
div.body { 
        padding: 0em;
        margin: 0em;
}

/*
item header の設定
*/
/* memo: tDiary だと h3。chalow でも設定によって h3 を出すことが可能 */
.clitemheader { 
        color: #606060;
	font-weight: bold;
        padding: 3px 3px 0px 3px;
}

h3 { 
        color: #606060;
	font-weight: bold;
	margin: 0px;
}

/*
イメージアンカーの設定
*/
/*div.day span.sanchor {*/
span.sanchor {
/*        background-image: url(dot-pink-16.png);
        background-position: bottom left;
	background-repeat: no-repeat;
        padding: 0px 0px 0px 0px;
        margin: 0px 0px 0px 0px;
        color: #fff;
        background-color: transparent;
*/
        font-size: xx-small;
}

/*
サブタイトルを含むセクション (item) の設定
*/
div.section { 
        border-color: #ffffff;
        border-style: solid;
        border-width: 1px;
	line-height: 130%;
        padding: 5px;
	margin: 5px 0px 15px 0px;
}

/*
item 中の引用の設定
*/
div.body blockquote { 
        border-color: #808080;
        border-style: solid;
        border-width: 1px;
	background-color: #f0f0f0;
	font-size: small;
	line-height: 120%;
	margin: 3px;
	padding: 3px;
}

/*
各 item の pre の設定 (各 item は pre で囲まれている)
*/
div.body pre {
	font-family: monospace;
	white-space: pre;
	line-height: 100%;
	margin: 0;
	padding: 0;
	font-size: x-small;
}

div.body p {
	margin: 0;
	padding: 0;
}

/*
カレンダーの設定
*/
.calendar {
	background-color: #fff8ff;
        text-align: left;
        font-size: x-small;
}

.calendar table {

}


/*
フッタの設定 (一番下の chalow のロゴ)
*/
.footer {
	text-align: right;
	font-size: x-small;
	margin: 0em;
}

p.footer a {
	font-weight: bold;
}

/* ツッコミ関連 */

div.comment {
        border-style: solid;
        border-color: #d0d0d0;
        border-width: 1px;
        margin: 0.5em;
        padding: 0.5em;
        font-size: small;
        background-color: #f0f0f0;
}

div.comment p {
	margin: 0.5em;
}

div.day span.canchor {
/*        background-image: url(dot-gray.png);
        background-position: bottom right;
        background-repeat: no-repeat;
        padding: 0px 16px 0px 0px;
        color: #fff;
        background-color: transparent;
*/
        font-size: small;
}

div.form {
        border-style: solid;
        border-color: #d0d0d0;
        border-width: 1px;
        margin: 0.5em;
        padding: 0.5em;
        background-color: #f0f0f0;
}

div.commentshort {
        margin: 0.3em;
}

div.commentbody {

}




/*
いろいろ
*/
img {
	margin: 2px;
}
/*
.section a img {
	margin: 2px;
	border-style: solid;
        border-width: 1px;
}
*/

/*
for chalow: Referrer by 日付リンク
*/
div .referer { 
  font-size: x-small;
  color: #808080;
  background-color: #f8f8f8;
  margin-top: 0.5em;
  padding: 0.2em;
}
div .referer a:link {color: #404040;}
div .referer a:visited {color: #606060;}

/*
for chalow: author of item
*/
div .itemauthor { 
  text-align: right;
  padding: 0.3em 0 0 0;
}
div .itemauthor span {
  font-size: small;
  border-color: #b0b0b0;
  border-style: solid;
  border-width: 0px 5px 1px 0px;
  color: #606060;
}

#content {
  position:relative;
  margin-left: 230px;
/*  margin-right: 180px;*/
  padding: 0px;	
}

#links {
  position:absolute;
  top:8.5em;
  left:5px;
  width: 225px;	
/*  float: left;
  margin-right: 5px;*/
  margin: 0px;
  padding: 0px;	
}


#footer {
  clear: both;
  margin-top: 5px;
}


.stdbox table {width: 100%; margin: 0;}
.stdbox a {text-decoration: none;}
.stdbox td {border: solid 1px #808080; padding: 3px; font-size: x-small;line-height: 130%;}
.stdbox ul {margin: 0; padding: 0}
.stdbox li {margin: 0 0 0 1em}
.stdbox dl {margin: 0;}
.stdbox dd {margin: 0 0 0 1em; padding: 0;}
.funcbox {border:solid 1px #808080;font-size:x-small;padding:3px;margin:2px;
      line-height: 120%;
}

.section table {border-collapse: collapse;}
.section td {border: solid 1px gray; padding: 3px;}
